@@ -1 +1,6 @@
 from natch.hashers.qualname_hasher import QualnameHasher
+
+
+__all__ = [
+    'QualnameHasher',
+]
